@@ -1,12 +1,11 @@
-from __future__ import print_function, unicode_literals
 from collections import deque
 from attr import attrs, attrib
-from attr.validators import provides
 from zope.interface import implementer
 from twisted.internet.interfaces import IPushProducer, IPullProducer
 from twisted.python import log
 from twisted.python.reflect import safe_str
 from .._interfaces import IDilationManager, IOutbound
+from ..util import provides
 from .connection import KCM, Ping, Pong, Ack
 
 
@@ -155,7 +154,7 @@ from .connection import KCM, Ping, Pong, Ack
 
 @attrs
 @implementer(IOutbound, IPushProducer)
-class Outbound(object):
+class Outbound:
     # Manage outbound data: subchannel writes to us, we write to transport
     _manager = attrib(validator=provides(IDilationManager))
     _cooperator = attrib()
@@ -341,7 +340,7 @@ class Outbound(object):
 # configurable Cooperator, a pause-immediately argument to startStreaming()
 @implementer(IPushProducer)
 @attrs(eq=False)
-class PullToPush(object):
+class PullToPush:
     _producer = attrib(validator=provides(IPullProducer))
     _unregister = attrib(validator=lambda _a, _b, v: callable(v))
     _cooperator = attrib()
