@@ -6,7 +6,7 @@ from ._interfaces import IJournal
 
 
 @implementer(IJournal)
-class Journal(object):
+class Journal:
     def __init__(self, save_checkpoint):
         self._save_checkpoint = save_checkpoint
         self._outbound_queue = []
@@ -30,7 +30,7 @@ class Journal(object):
 
 
 @implementer(IJournal)
-class ImmediateJournal(object):
+class ImmediateJournal:
     def __init__(self):
         pass
 
