@@ -19,6 +19,7 @@ from ..._dilation.connector import (Connector,
                                     InboundConnectionFactory,
                                     PROLOGUE_LEADER, PROLOGUE_FOLLOWER,
                                     )
+from ..._status import DilationHint
 from .common import clear_mock_calls
 
 
@@ -88,7 +89,7 @@ def make_connector(listen=True, tor=False, relay=None, role=roles.LEADER):
     if tor:
         h.tor = mock.Mock()
     timing = None
-    h.side = u"abcd1234abcd5678"
+    h.side = "abcd1234abcd5678"
     h.role = role
     c = Connector(h.dilation_key, h.relay, h.manager, h.reactor, h.eq,
                   not listen, h.tor, timing, h.side, h.role)
@@ -180,7 +181,7 @@ def test_basic():
     c.got_hints([hint])
 
     # received hints don't get published
-    assert h.manager.mock_calls == []
+    assert h.manager.mock_calls == [mock.call._hint_status([DilationHint(url='foo:55', is_direct=True)])]
     # they just schedule a connection
     assert c._schedule_connection.mock_calls == \
                      [mock.call(0.0, DirectTCPV1Hint("foo", 55, 0.0),
@@ -317,16 +318,22 @@ def test_initial_relay():
     c, h = make_connector(listen=False, relay="tcp:foo:55", role=roles.LEADER)
     c._schedule_connection = mock.Mock()
     c.start()
-    assert h.manager.mock_calls == \
-                     [mock.call.send_hints([{"type": "relay-v1",
-                                             "hints": [
-                                                 {"type": "direct-tcp-v1",
-                                                  "hostname": "foo",
-                                                  "port": 55,
-                                                  "priority": 0.0
-                                                  },
-                                                 ],
-                                             }])]
+    assert h.manager.mock_calls == [
+        mock.call.send_hints([
+            {
+                "type": "relay-v1",
+                "hints": [
+                    {
+                        "type": "direct-tcp-v1",
+                        "hostname": "foo",
+                        "port": 55,
+                        "priority": 0.0
+                    },
+                ],
+            },
+        ]),
+        mock.call._hint_status([DilationHint(url='foo:55', is_direct=False)]),
+    ]
     assert c._schedule_connection.mock_calls == \
                      [mock.call(0.0, DirectTCPV1Hint("foo", 55, 0.0),
                                 is_relay=True)]
@@ -338,7 +345,9 @@ def test_tor_no_manager():
     c.start()
     hint = TorTCPV1Hint("foo", 55, 0.0)
     c.got_hints([hint])
-    assert h.manager.mock_calls == []
+    assert h.manager.mock_calls == [
+        mock.call._hint_status([]),
+    ]
     assert c._schedule_connection.mock_calls == []
 
 def test_tor_with_manager():
@@ -366,7 +375,7 @@ def test_one_leader():
     c._start_listener = start_listener
     c._schedule_connection = mock.Mock()
     c.start()
-    assert c._listeners == set([lp])
+    assert c._listeners == {lp}
 
     p1 = mock.Mock()  # DilatedConnectionProtocol instance
     c.add_candidate(p1)
@@ -388,7 +397,7 @@ def test_one_follower():
     c._start_listener = start_listener
     c._schedule_connection = mock.Mock()
     c.start()
-    assert c._listeners == set([lp])
+    assert c._listeners == {lp}
 
     p1 = mock.Mock()  # DilatedConnectionProtocol instance
     c.add_candidate(p1)
@@ -454,4 +463,4 @@ def test_describe_inbound():
     assert describe_inbound(IPv6Address("TCP", "::1", 1234)) == \
                      "<-tcp:[::1]:1234"
     other = "none-of-the-above"
-    assert describe_inbound(other) == "<-%r" % other
+    assert describe_inbound(other) == f"<-{other!r}"
